@@ -17,9 +17,9 @@ sub mvp_multivalue_args { qw(
                         ) }
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-01-08'; # DATE
+our $DATE = '2024-01-12'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.078'; # VERSION
+our $VERSION = '0.079'; # VERSION
 
 sub weave_section {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -133,17 +133,26 @@ sub weave_section {
                 last unless $self->show_source;
 
                 require Data::Clone;
-                require Data::Dump;
+                require Data::Dump::SortKeys;
                 require Data::Sah::Util::Type;
+                require Sort::Sub;
+                require Sort::Sub::sah_schema_clause; # for scan_prereqs
 
                 my @pod;
                 my $sch = Data::Clone::clone($sch);
                 delete $sch->[1]{description};
                 delete $sch->[1]{examples};
 
-                my $dump = Data::Dump::dump($sch);
-                $dump =~ s/^/ /mg;
-                push @pod, $dump, "\n\n";
+                {
+                    my $sorter = Sort::Sub::get_sorter("sah_schema_clause");
+                    local $Data::Dump::SortKeys::SORT_KEYS = sub {
+                        my $hash = shift;
+                        sort { $sorter->($a,$b) } keys %$hash;
+                    };
+                    my $dump = Data::Dump::SortKeys::dump($sch);
+                    $dump =~ s/^/ /mg;
+                    push @pod, $dump, "\n\n";
+                }
 
                 # link to base schema/type
                 my $type = Data::Sah::Util::Type::get_type($sch);
@@ -446,7 +455,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.078 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
+This document describes version 0.079 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-12.
 
 =head1 SYNOPSIS
 
